<?php
namespace App\Model;

use Nette;
use App\Model;

/**
 * Base Class
 */
abstract class Base extends Nette\Object{

	/**
	 * @var Nette\Database\Context
	 */
	protected $db;

	/**
	 * @var Nette\Http\Session
	 */
	public $session;

	/** @var User */
	public $user;

	/**
	 * @var int id of logged user
	 */
	public $userId;

	/**
	 * ActiveRow of active user
	 */
	public $UAR;


	/**
	 * Set database and session
	 *
	 * @param Nette\Database\Context $db
	 * @param Nette\Http\Session $session
	 */
	public function __construct(Nette\Database\Context $db, Nette\Http\Session $session){

		try{
			$this->db = $db;
			$this->session = $session;

		} catch(PDOException $e){
			die($e->getMessage());
		}
	}


	/**
	 * Set ActiveRow of logged user.
	 *
	 * @param $id of active user
	 */
	public function setUserAR($id){
		$this->UAR = $this->db->table('users')->get($id);
	}

	/**
	 * Set Nette user model.
	 *
	 * @param $class object Nette\Security\User
	 */
	public function setUserMO($class){
		$this->user = $class;
		if ($this->user->isLoggedIn()) {
			$this->userId = $this->user->getIdentity()->getId();
		} else {
			$this->userId = null;
		}
	}


	public function setUserId($id){
		$this->userId = $id;
		return true;
	}
	public function getUserId(){
		return $this->userId;
	}

	/**
	 * Closes session before time-consuming operations
	 */
	public function session_close(){
		if($this->session->exists()){
			$this->session->close();
		}
	}


	/**
	 * Set new "position" in db of selected IDs
	 * @param $table string
	 * @param $ids array of id to resort
	 */
	public function resortThings($table, $ids){
		$order = [];
		$position = 1;
		$ids = array_keys($ids);
		foreach ($ids as $id) {
			$order[$id] = $position;
			$position +=1;
		}
		$idecka = implode(',', $ids);
		$sql = 'UPDATE '.$table.' SET position = CASE id ';
		foreach($order as $id => $position){
			$sql .= sprintf('WHEN %d THEN %d ', $id, $position);
		}
		$sql .= 'END WHERE id IN ('.$idecka.')';
		$this->db->query($sql);
	}


	/**
	 * Convert original to hashed string.
	 * @param $what string original
	 * @return string hashed
	 */
	public function encryptInfo($what){
		//secret combination
	}

	/**
	 * Convert hashed to original string.
	 * @param $what string hashed
	 * @return string original
	 */
	public function decryptInfo($what){
		//secret combination
	}


	/**
	 * Get specific info about logged user from db. (like. name, email...)
	 * @param $what string
	 * @return bool|string
	 */
	public function info($what){
		if($what == 'password' || $what == 'secret'){
			return false;
		}
		return $this->UAR[$what];
	}


	/**
	 * Convert string with elements from jqueryUI lib to array.
	 * @param $inp string from jqueryUI sorting "toArray"
	 * @return array of elements
	 */
	public function makeArrayFromStr($inp){
		$list = explode(',', $inp);
		foreach ($list as $element) {
			$num = explode('_"', $element);
			$id = $num[1];
			$order[] = (int)$id;
		}
		return $order;
	}
}